@@ -1,10 +1,19 @@
 import logging
 from abc import abstractmethod
-from typing import Awaitable, Callable, Set, Tuple
+from typing import Awaitable
+from typing import Callable
+from typing import Optional
+from typing import Set
+from typing import Tuple
 
 from dipdup.config import HTTPConfig
+from dipdup.datasources.subscription import HeadSubscription
+from dipdup.datasources.subscription import Subscription
+from dipdup.datasources.subscription import SubscriptionManager
 from dipdup.http import HTTPGateway
-from dipdup.models import BigMapData, HeadBlockData, OperationData
+from dipdup.models import BigMapData
+from dipdup.models import HeadBlockData
+from dipdup.models import OperationData
 from dipdup.utils import FormattedLogger
 
 _logger = logging.getLogger('dipdup.datasource')
@@ -30,17 +39,23 @@ class Datasource(HTTPGateway):
 
 
 class IndexDatasource(Datasource):
-    def __init__(self, url: str, http_config: HTTPConfig) -> None:
+    def __init__(self, url: str, http_config: HTTPConfig, merge_subscriptions: bool = False) -> None:
         super().__init__(url, http_config)
         self._on_head: Set[HeadCallbackT] = set()
         self._on_operations: Set[OperationsCallbackT] = set()
         self._on_big_maps: Set[BigMapsCallbackT] = set()
         self._on_rollback: Set[RollbackCallbackT] = set()
+        self._subscriptions: SubscriptionManager = SubscriptionManager(merge_subscriptions)
+        self._subscriptions.add(HeadSubscription())
 
     @property
     def name(self) -> str:
         return self._http._url
 
+    @abstractmethod
+    async def subscribe(self) -> None:
+        ...
+
     def on_head(self, fn: HeadCallbackT) -> None:
         self._on_head.add(fn)
 
@@ -68,3 +83,9 @@ class IndexDatasource(Datasource):
     async def emit_rollback(self, from_level: int, to_level: int) -> None:
         for fn in self._on_rollback:
             await fn(self, from_level, to_level)
+
+    def set_sync_level(self, subscription: Optional[Subscription], level: int) -> None:
+        self._subscriptions.set_sync_level(subscription, level)
+
+    def get_sync_level(self, subscription: Subscription) -> Optional[int]:
+        return self._subscriptions.get_sync_level(subscription)
